@@ -238,7 +238,7 @@ class Microservices(BaseClass, ABC):
         """
 
         if topic == "Errores_criticos":
-            return None
+            self._send(topic, data, id_transaction)
 
         id_trans = id_transaction if id_transaction is None else str(
             uuid.uuid4())
